@@ -1,7 +1,3 @@
-#' @importFrom mlr3cluster TaskClust
-#' @export
-mlr3cluster::TaskClust
-
 #' @importFrom mlr3cluster as_task_clust
 #' @export
 mlr3cluster::as_task_clust
