@@ -1,22 +1,14 @@
-#' @importFrom mlr3fselect mlr_fselectors
+#' @importFrom mlr3fselect auto_fselector
 #' @export
-mlr3fselect::mlr_fselectors
+mlr3fselect::auto_fselector
 
-#' @importFrom mlr3fselect fs
+#' @importFrom mlr3fselect callback_batch_fselect
 #' @export
-mlr3fselect::fs
+mlr3fselect::callback_batch_fselect
 
-#' @importFrom mlr3fselect AutoFSelector
+#' @importFrom mlr3fselect ensemble_fselect
 #' @export
-mlr3fselect::AutoFSelector
-
-#' @importFrom mlr3fselect FSelectInstanceSingleCrit
-#' @export
-mlr3fselect::FSelectInstanceSingleCrit
-
-#' @importFrom mlr3fselect FSelectInstanceMultiCrit
-#' @export
-mlr3fselect::FSelectInstanceMultiCrit
+mlr3fselect::ensemble_fselect
 
 #' @importFrom mlr3fselect extract_inner_fselect_results
 #' @export
@@ -26,20 +18,26 @@ mlr3fselect::extract_inner_fselect_results
 #' @export
 mlr3fselect::extract_inner_fselect_archives
 
-#' @importFrom mlr3fselect fselect
-#' @export
-mlr3fselect::fselect
-
 #' @importFrom mlr3fselect fselect_nested
 #' @export
 mlr3fselect::fselect_nested
 
-#' @importFrom mlr3fselect auto_fselector
+#' @importFrom mlr3fselect fselect
 #' @export
-mlr3fselect::auto_fselector
+mlr3fselect::fselect
+
+#' @importFrom mlr3fselect mlr_fselectors
+#' @export
+mlr3fselect::mlr_fselectors
+
+#' @importFrom mlr3fselect fs
+#' @export
+mlr3fselect::fs
+
+#' @importFrom mlr3fselect fss
+#' @export
+mlr3fselect::fss
 
 #' @importFrom mlr3fselect fsi
 #' @export
 mlr3fselect::fsi
-
-
